import type { Luvio, PathSelection, AdapterContext, Snapshot, FulfilledSnapshot, StaleSnapshot, StoreLookup } from '@luvio/engine';
import type { ListInfoRepresentation } from '../generated/types/ListInfoRepresentation';
import type { ListReferenceRepresentation } from '../generated/types/ListReferenceRepresentation';
import type { RecordRepresentation } from '../generated/types/RecordRepresentation';
import type { ListRecordCollectionRepresentation } from '../generated/types/ListRecordCollectionRepresentation';
export interface ListReferenceQuery {
    listViewId?: string;
    objectApiName?: string;
    listViewApiName?: string;
}
/**
 * Adds a list reference so it can be retrieved with #getListReference later.
 *
 * @param listRef list reference
 */
export declare function addListReference(listRef: ListReferenceRepresentation, context: AdapterContext): void;
/**
 * Adds a list reference with some specified key so it can be retrieved with #getListReference later.
 *
 * @param listRef
 * @param context
 * @param id - Specified Id to use in the context key
 */
export declare function addListReferenceWithId(listRef: ListReferenceRepresentation, context: AdapterContext, id: string | null): void;
/**
 * Returns a list reference from the store if it's present.
 *
 * @param query list view to look for
 * @param luvio Luvio
 */
export declare function getListReference(query: ListReferenceQuery, context: AdapterContext): ListReferenceRepresentation | undefined;
/**
 * Reader selections to copy a list info
 */
export declare const LIST_INFO_SELECTIONS: PathSelection[];
/**
 * List info private memebers
 */
export declare const LIST_INFO_PRIVATES: string[];
/**
 * Retrieves the snapshot of the list info corresponding to the specified list
 * reference from the store.
 *
 * @param listRef list reference
 * @param luvio Luvio
 */
export declare function getListInfo(luvio: Luvio, listRef: ListReferenceRepresentation, storeLookup: StoreLookup<ListInfoRepresentation>): Snapshot<ListInfoRepresentation>;
export interface ServerDefaultable {
    sortBy?: string[];
}
export interface ServerDefaults {
    sortBy?: string[];
}
/**
 * Update the default values based on a server response.
 *
 * @param config getListUi config
 * @param serverResponse ListUiRepresentation from the server
 */
export declare function addServerDefaults(config: ListReferenceQuery & ServerDefaultable, records: ListRecordCollectionRepresentation, listReference: ListReferenceRepresentation, context: AdapterContext): void;
/**
 * Returns default values observed on previous requests for a list.
 *
 * @param config getListUi config
 * @returns defaults from previous requests for this list, or {} if no defaults are known
 */
export declare function getServerDefaults(config: ListReferenceQuery, context: AdapterContext): ServerDefaults;
export interface ListFields {
    getRecordSelectionFieldSets: () => [string[], string[]];
    processRecords: (records: RecordRepresentation[]) => ListFields;
}
export declare function listFields(luvio: Luvio, { fields, optionalFields, sortBy, }: {
    fields?: string[];
    optionalFields?: string[];
    sortBy?: string[];
}, listInfo: ListInfoRepresentation): ListFields;
export declare function isListInfoSnapshotWithData(snapshot: Snapshot<unknown>): snapshot is FulfilledSnapshot<ListInfoRepresentation> | StaleSnapshot<ListInfoRepresentation>;
interface notifyAllListRecordInput {
    objectApiName: string;
    listViewApiName: string;
}
export declare function setupNotifyAllListRecordUpdateAvailable(luvio: Luvio): (notifyInput: notifyAllListRecordInput) => Promise<void>;
interface notifyAllListInfoSummaryInput {
    objectApiName: string;
    recentLists: boolean | undefined;
}
export declare function setupNotifyAllListInfoSummaryUpdateAvailable(luvio: Luvio): (notifyInput: notifyAllListInfoSummaryInput) => Promise<void>;
export {};
